==> apache-karaf-4.0.10-src.zip: apache-karaf-4.0.10/shell/core/src/main/java/org/apache/karaf/shell/api/console/Command.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.shell.api.console;

/**
 * A <code>Command</code> is a named
 * {@link org.apache.karaf.shell.api.console.Function}
 * which also provides completion.
 */
public interface Command extends Function {

    /**
     * Retrieve the scope of this command.
     */
    String getScope();

    /**
     * Retrieve the name of this command.
     */
    String getName();

    /**
     * Retrieve the description of this command.
     * This short command description will be printed
     * when using the <code>help</code> command.
     */
    String getDescription();

    /**
     * Retrieve the completer associated with this command.
     *
     * @param scoped whether the command is invoked from a subshell or not
     * @return the {@link Completer} to use
     */
    Completer getCompleter(boolean scoped);

    /**
     * Retrieve the parser associated with this command or null for the default one.
     *
     * @return
     */
    Parser getParser();

}

==> apache-karaf-4.4.10-src.zip: apache-karaf-4.4.10/shell/core/src/main/java/org/apache/karaf/shell/api/console/Command.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.shell.api.console;

/**
 * A <code>Command</code> is a named
 * {@link org.apache.karaf.shell.api.console.Function}
 * which also provides completion.
 */
public interface Command extends Function {

    /**
     * Retrieve the scope of this command.
     *
     * @return the command scope.
     */
    String getScope();

    /**
     * Retrieve the name of this command.
     *
     * @return the command name.
     */
    String getName();

    /**
     * Retrieve the description of this command.
     * This short command description will be printed
     * when using the <code>help</code> command.
     *
     * @return the command description.
     */
    String getDescription();

    /**
     * Retrieve the completer associated with this command.
     *
     * @param scoped whether the command is invoked from a subshell or not
     * @return the {@link Completer} to use
     */
    Completer getCompleter(boolean scoped);

    /**
     * Retrieve the parser associated with this command or null for the default one.
     *
     * @return the command parser.
     */
    Parser getParser();

}
